@@ -97,7 +97,7 @@ init_custom_header (const gchar *apikey, gboolean content_type)
  * @param[in] apikey        Optional Api key for Authorization header.
  *
  * @return Pointer to a `gvm_http_response_t` containing status code and body.
- *         Must be freed using `gvm_http_response_cleanup()`.
+ *         Must be freed using `gvm_http_response_free()`.
  */
 static gvm_http_response_t *
 agent_controller_send_request (agent_controller_connector_t conn,
@@ -816,7 +816,7 @@ agent_controller_get_agents (agent_controller_connector_t conn)
     {
       g_warning ("%s: Received HTTP status %ld", __func__,
                  response->http_status);
-      gvm_http_response_cleanup (response);
+      gvm_http_response_free (response);
       return NULL;
     }
 
@@ -826,7 +826,7 @@ agent_controller_get_agents (agent_controller_connector_t conn)
       g_warning ("%s: Failed to parse JSON array", __func__);
       if (root)
         cJSON_Delete (root);
-      gvm_http_response_cleanup (response);
+      gvm_http_response_free (response);
       return NULL;
     }
 
@@ -852,7 +852,7 @@ agent_controller_get_agents (agent_controller_connector_t conn)
   agent_list->count = valid_index;
 
   cJSON_Delete (root);
-  gvm_http_response_cleanup (response);
+  gvm_http_response_free (response);
 
   return agent_list;
 }
@@ -899,7 +899,7 @@ agent_controller_update_agents (agent_controller_connector_t conn,
       return AGENT_RESP_ERR;
     }
 
-  if (response->http_status == 400)
+  if (response->http_status == 400 || response->http_status == 422)
     {
       if (response->data)
         {
@@ -907,10 +907,14 @@ agent_controller_update_agents (agent_controller_connector_t conn,
         }
       else
         {
-          push_error (errors, "Request rejected (400), empty response body.");
+          gchar *msg =
+            g_strdup_printf ("Request rejected (%ld), empty response body.",
+                             response->http_status);
+          push_error (errors, msg);
+          g_free (msg);
         }
 
-      gvm_http_response_cleanup (response);
+      gvm_http_response_free (response);
       return AGENT_RESP_ERR;
     }
 
@@ -918,11 +922,11 @@ agent_controller_update_agents (agent_controller_connector_t conn,
     {
       g_warning ("%s: Received HTTP status %ld", __func__,
                  response->http_status);
-      gvm_http_response_cleanup (response);
+      gvm_http_response_free (response);
       return AGENT_RESP_ERR;
     }
 
-  gvm_http_response_cleanup (response);
+  gvm_http_response_free (response);
 
   return AGENT_RESP_OK;
 }
@@ -986,11 +990,11 @@ agent_controller_delete_agents (agent_controller_connector_t conn,
     {
       g_warning ("%s: Received HTTP status %ld", __func__,
                  response->http_status);
-      gvm_http_response_cleanup (response);
+      gvm_http_response_free (response);
       return AGENT_RESP_ERR;
     }
 
-  gvm_http_response_cleanup (response);
+  gvm_http_response_free (response);
 
   return AGENT_RESP_OK;
 }
@@ -1127,7 +1131,7 @@ agent_controller_get_scan_agent_config (agent_controller_connector_t conn)
   if (response->http_status < 200 || response->http_status >= 300)
     {
       g_warning ("%s: HTTP %ld", __func__, response->http_status);
-      gvm_http_response_cleanup (response);
+      gvm_http_response_free (response);
       return NULL;
     }
 
@@ -1135,7 +1139,7 @@ agent_controller_get_scan_agent_config (agent_controller_connector_t conn)
   if (!root)
     {
       g_warning ("%s: JSON parse failed", __func__);
-      gvm_http_response_cleanup (response);
+      gvm_http_response_free (response);
       return NULL;
     }
 
@@ -1143,7 +1147,7 @@ agent_controller_get_scan_agent_config (agent_controller_connector_t conn)
     agent_controller_parse_scan_agent_config (root);
 
   cJSON_Delete (root);
-  gvm_http_response_cleanup (response);
+  gvm_http_response_free (response);
   return cfg;
 }
 
@@ -1187,7 +1191,7 @@ agent_controller_update_scan_agent_config (
       return AGENT_RESP_ERR;
     }
 
-  if (response->http_status == 400)
+  if (response->http_status == 400 || response->http_status == 422)
     {
       if (response->data)
         {
@@ -1195,21 +1199,25 @@ agent_controller_update_scan_agent_config (
         }
       else
         {
-          push_error (errors, "Request rejected (400), empty response body.");
+          gchar *msg =
+            g_strdup_printf ("Request rejected (%ld), empty response body.",
+                             response->http_status);
+          push_error (errors, msg);
+          g_free (msg);
         }
 
-      gvm_http_response_cleanup (response);
+      gvm_http_response_free (response);
       return AGENT_RESP_ERR;
     }
 
   if (response->http_status < 200 || response->http_status >= 300)
     {
       g_warning ("%s: HTTP %ld", __func__, response->http_status);
-      gvm_http_response_cleanup (response);
+      gvm_http_response_free (response);
       return AGENT_RESP_ERR;
     }
 
-  gvm_http_response_cleanup (response);
+  gvm_http_response_free (response);
   return AGENT_RESP_OK;
 }
 
@@ -1243,7 +1251,7 @@ agent_controller_get_agents_with_updates (agent_controller_connector_t conn)
     {
       g_warning ("%s: Received HTTP status %ld", __func__,
                  response->http_status);
-      gvm_http_response_cleanup (response);
+      gvm_http_response_free (response);
       return NULL;
     }
 
@@ -1253,7 +1261,7 @@ agent_controller_get_agents_with_updates (agent_controller_connector_t conn)
       g_warning ("%s: Failed to parse JSON array", __func__);
       if (root)
         cJSON_Delete (root);
-      gvm_http_response_cleanup (response);
+      gvm_http_response_free (response);
       return NULL;
     }
 
@@ -1275,7 +1283,77 @@ agent_controller_get_agents_with_updates (agent_controller_connector_t conn)
   agent_list->count = valid_index;
 
   cJSON_Delete (root);
-  gvm_http_response_cleanup (response);
+  gvm_http_response_free (response);
 
   return agent_list;
-}
\ No newline at end of file
+}
+
+/**
+ * @brief Build a JSON payload for creating a scan in the agent controller.
+ *
+ * @param[in] agents List of agents to include in the payload.
+ *
+ * @return A newly allocated JSON string representing the create-scan payload.
+ *         The caller is responsible for freeing the returned string using
+ *         g_free().
+ */
+gchar *
+agent_controller_build_create_scan_payload (
+  agent_controller_agent_list_t agents)
+{
+  if (!agents)
+    return NULL;
+
+  cJSON *root = cJSON_CreateObject ();
+
+  cJSON *target = cJSON_CreateObject ();
+  cJSON *hosts = cJSON_CreateArray ();
+
+  // Iterate over agents and add agent_id to "hosts"
+  for (int i = 0; i < agents->count; ++i)
+    {
+      agent_controller_agent_t agent = agents->agents[i];
+      if (!agent || !agent->agent_id)
+        continue;
+
+      if (agent && agent->agent_id && *agent->agent_id)
+        cJSON_AddItemToArray (hosts, cJSON_CreateString (agent->agent_id));
+    }
+
+  cJSON_AddItemToObject (target, "hosts", hosts);
+  cJSON_AddItemToObject (root, "target", target);
+
+  // vts (empty array)
+  cJSON *vts = cJSON_CreateArray ();
+  cJSON_AddItemToObject (root, "vts", vts);
+
+  gchar *payload = cJSON_PrintUnformatted (root);
+  cJSON_Delete (root);
+
+  return payload;
+}
+
+/**
+ * @brief Extract the scan_id from a create-scan response body.
+ *
+ * @param[in] body JSON string response from the agent controller.
+ *
+ * @return A newly allocated string containing the scan_id, or NULL if not
+ * found. Caller must free with g_free().
+ */
+gchar *
+agent_controller_get_scan_id (const gchar *body)
+{
+  if (!body)
+    return NULL;
+
+  cJSON *root = cJSON_Parse (body);
+  if (!root)
+    return NULL;
+
+  const char *scan_id = gvm_json_obj_str (root, "scan_id");
+  gchar *result = scan_id ? g_strdup (scan_id) : NULL;
+
+  cJSON_Delete (root);
+  return result;
+}
