@@ -90,8 +90,9 @@ auth_method_name (auth_method_t method)
 int
 auth_method_name_valid (const gchar *name)
 {
-  int i;
-  for (i = 0; i < 1000; i++)
+  if (name == NULL)
+    return 0;
+  for (int i = 0; i < 1000; i++)
     if (authentication_methods[i] == NULL)
       break;
     else if (strcmp (authentication_methods[i], name) == 0)
@@ -161,13 +162,14 @@ gvm_auth_init (void)
 /**
  * @brief Generate a hexadecimal representation of a message digest.
  *
- * @param gcrypt_algorithm The libgcrypt message digest algorithm used to
- * create the digest (e.g. GCRY_MD_MD5; see the enum gcry_md_algos in
- * gcrypt.h).
- * @param digest The binary representation of the digest.
+ * @param gcrypt_algorithm  The libgcrypt message digest algorithm used to
+ *                          create the digest (e.g. GCRY_MD_MD5; see the enum
+ *                          gcry_md_algos in gcrypt.h).
+ * @param digest  The binary representation of the digest. Must be big enough
+ *                for the gcrypt_algorithm.
  *
  * @return A pointer to the hexadecimal representation of the message digest
- * or NULL if an unavailable message digest algorithm was selected.
+ *         or NULL if an unavailable message digest algorithm was selected.
  */
 gchar *
 digest_hex (int gcrypt_algorithm, const guchar *digest)
