@@ -104,22 +104,33 @@ cmp_versions (const char *version1, const char *version2)
     }
 
   if (part1 == NULL && part2 == NULL)
-    return release_state2 - release_state1;
+    {
+      g_free (ver1);
+      g_free (ver2);
+      return release_state2 - release_state1;
+    }
 
   if (is_text (part1) || is_text (part2))
     {
-      if (part1)
-        g_free (part1);
-      if (part2)
-        g_free (part2);
-      return (-5); // undefined
+      g_free (ver1);
+      g_free (ver2);
+      g_free (part1);
+      g_free (part2);
+      return -5; // undefined
     }
 
   rs1 = get_release_state (ver1, index1);
   rs2 = get_release_state (ver2, index2);
 
+  g_free (ver1);
+  g_free (ver2);
+
   if ((rs1 && release_state1) || (rs2 && release_state2))
-    return (-5); // undefined
+    {
+      g_free (part1);
+      g_free (part2);
+      return -5; // undefined
+    }
 
   if (part1 == NULL)
     {
@@ -143,26 +154,19 @@ cmp_versions (const char *version1, const char *version2)
 
   if (rs1 && rs2)
     ret = rs2 - rs1;
-
-  if (rs1)
+  else if (rs1)
     ret = -1;
-
-  if (rs2)
+  else if (rs2)
     ret = 1;
-
-  if (!rs1 && !rs2 && atoi (part1) < atoi (part2))
+  else if (atoi (part1) < atoi (part2))
     ret = -1;
-
-  if (!rs1 && !rs2 && atoi (part1) == atoi (part2))
+  else if (atoi (part1) == atoi (part2))
     ret = 0;
-
-  if (!rs1 && !rs2 && atoi (part1) > atoi (part2))
+  else if (atoi (part1) > atoi (part2))
     ret = 1;
 
   g_free (part1);
   g_free (part2);
-  g_free (ver1);
-  g_free (ver2);
   return ret;
 }
 
@@ -257,7 +261,7 @@ prepare_version_string (const char *version)
 
   prep_version[index_pv] = '\0';
   g_free (ver);
-  return (g_strdup (prep_version));
+  return g_strdup (prep_version);
 }
 
 /**
@@ -337,8 +341,9 @@ is_text (const char *part)
 {
   if (!part)
     return FALSE;
-  if (strcmp (part, "dev") == 0 || strcmp (part, "alpha") == 0
-      || strcmp (part, "beta") == 0 || strcmp (part, "rc") == 0)
+  if (strcmp (part, "dev") == 0 || strcmp (part, "development") == 0
+      || strcmp (part, "alpha") == 0 || strcmp (part, "beta") == 0
+      || strcmp (part, "rc") == 0)
     return FALSE;
   if (g_ascii_isdigit (*part))
     return FALSE;
